@@ -86,6 +86,8 @@ class PullRequest:
 
         if self.merge_once is True:
             body += "**Ignore:** Close this PR and it will not be recreated again.\n"
+        else:
+            body += "**Ignore:** This PR will be recreated if closed.\n"
 
         body += """
 ---
@@ -119,6 +121,21 @@ class Repository:
         """
         raise NotImplementedError("class does not implement Repository.base_branch()")
 
+    def can_merge_pull_request(self, identifier: Any) -> bool:
+        """
+        Checks if a pull request can be merged.
+
+        Use this function to check if a Source, e.g. GitHub, indicates that merge
+        conflicts exist.
+
+        :param identifier: Data to identify the pull request as returned by find_pull_request.
+        :return: Indicates if the pull request can be merged.
+        :rtype: bool
+        """
+        raise NotImplementedError(
+            "class does not implement Repository.can_merge_pull_request()"
+        )
+
     @property
     def clone_url(self) -> str:
         """
@@ -152,6 +169,11 @@ class Repository:
             "class does not implement Repository.create_pull_request()"
         )
 
+    def delete_branch(self, identifier: Any) -> None:
+        raise NotImplementedError(
+            "class does not implement Repository.delete_pull_request()"
+        )
+
     def find_pull_request(self, branch: str) -> Union[Any, None]:
         """
         Finds and returns the pull request opened by rcmt.
@@ -235,7 +257,6 @@ class Repository:
         Merges a pull request.
 
         :param identifier: Data to identify the pull request as returned by find_pull_request.
-        :rtype: None
         """
         raise NotImplementedError(
             "class does not implement Repository.merge_pull_request()"
